@@ -4,16 +4,18 @@ use strict;
 
 package Date::Simple;
 
-sub ymd {
-    my $days = &ymd_to_days;
+sub _ymd {
+    my ($o,@args)=@_;
+    my $c=ref($o)||$o;
+    my $days = ymd_to_days(@args);
     return undef unless defined ($days);
-    return (bless (\$days, __PACKAGE__));
+    return (bless (\$days, $c));
 }
 
-sub d8 {
-    my ($d8) = @_;
+sub _d8 {
+    my ($o,$d8) = @_;
     my @ymd = $d8 =~ m/^(\d{4})(\d\d)(\d\d)$/ or return undef;
-    return ymd (@ymd);
+    return $o->_ymd(@ymd);
 }
 
 # Precise integer arithmetic functions unfortunately missing from
@@ -152,17 +154,23 @@ sub _add {
     if ($diff !~ /^-?\d+$/) {
 	Carp::croak ("Date interval must be an integer");
     }
-    return (bless (\ ($$date + $diff), ref($date)));
+    my $new_date = bless (\ ($$date + $diff), ref($date));
+    $new_date->default_format($date->default_format);
+    return $new_date;
 }
 
 sub _subtract {
     my ($left, $right, $reverse) = @_;
 
+    my $new_date;
+
     if ($reverse) {
 	Carp::croak ("Can't subtract a date from a non-date");
     }
     if (ref($right) eq '' && $right =~ /^-?\d+$/) {
-	return (bless (\ ($$left - $right), ref($left)));
+    $new_date = bless (\ ($$left - $right), ref($left));
+    $new_date->default_format($left->default_format);
+    return $new_date;
     }
     return ($$left - $$right);
 }
